==> t4gpd-0.7.1.tar.gz: t4gpd-0.7.1/t4gpd/graph/STToRoadsSections.py <==
'''
Created on 17 juin 2020

@author: tleduc

Copyright 2020 Thomas Leduc

This file is part of t4gpd.

t4gpd is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

t4gpd is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with t4gpd.  If not, see <https://www.gnu.org/licenses/>.
'''
from geopandas.geodataframe import GeoDataFrame

from t4gpd.commons.GeoProcess import GeoProcess
from t4gpd.commons.IllegalArgumentTypeException import IllegalArgumentTypeException
from t4gpd.commons.graph.UrbanGraphLibOld import UrbanGraphLibOld


class STToRoadsSections(GeoProcess):
    '''
    classdocs
    '''

    def __init__(self, inputGdf, withoutCulDeSac=False):
        '''
        Constructor
        '''
        if not isinstance(inputGdf, GeoDataFrame):
            raise IllegalArgumentTypeException(inputGdf, 'GeoDataFrame')
        self.inputGdf = inputGdf
        self.withoutCulDeSac = withoutCulDeSac

    def run(self):
        ga = UrbanGraphLibOld()
        ga.add([row for _, row in self.inputGdf.iterrows()])

        if self.withoutCulDeSac:
            rs = ga.getUniqueRoadsSectionsWithoutCulDeSac()
        else:
            rs = ga.getUniqueRoadsSections()

        return GeoDataFrame(rs, crs=self.inputGdf.crs)

==> t4gpd-0.9.7.tar.gz: t4gpd-0.9.7/t4gpd/graph/STToRoadsSections.py <==
'''
Created on 17 juin 2020

@author: tleduc

Copyright 2020-2023 Thomas Leduc

This file is part of t4gpd.

t4gpd is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

t4gpd is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with t4gpd.  If not, see <https://www.gnu.org/licenses/>.
'''
from geopandas import GeoDataFrame
from t4gpd.commons.GeoProcess import GeoProcess
from t4gpd.commons.IllegalArgumentTypeException import IllegalArgumentTypeException
from t4gpd.commons.graph.UrbanGraphFactory import UrbanGraphFactory


class STToRoadsSections(GeoProcess):
    '''
    classdocs
    '''

    def __init__(self, inputGdf, withoutCulDeSac=False):
        '''
        Constructor
        '''
        if not isinstance(inputGdf, GeoDataFrame):
            raise IllegalArgumentTypeException(inputGdf, "GeoDataFrame")
        self.inputGdf = inputGdf
        self.withoutCulDeSac = withoutCulDeSac

    def run(self):
        ug = UrbanGraphFactory.create(self.inputGdf, method=None)
        if self.withoutCulDeSac:
            return ug.getUniqueRoadsSectionsWithoutCulDeSac()
        return ug.getUniqueRoadsSections()
